\name{USPS-package}
\alias{USPS-package}
\docType{package}
\title{Unsupervised and Supervised Propensity Score Adjustment for Bias and Confounding}
\description{Define Local Treatment Differences (LTDs) and Local Average Outcomes (LAOs) within
  Clusters of patients who have been relatively well-matched on their baseline X-covariates.  The
  resulting distribution of LTD effect-size estimates can be interpreted much like a Bayesion
  posterior yet has been formed, via Nonparametric Preprocessing, in a purely Objective way.
}
\details{
  \tabular{ll}{
  Package: \tab USPS\cr
  Type: \tab Package\cr
  Version: \tab 1.3\cr
  Date: \tab 2018-4-2\cr
  License: \tab GPL\cr
  }

  SUPERVISED OUTCOME BINNING AND SMOOTHING VIA ESTIMATED PROPENSITY SCORES:
  
  Once one has fitted a somewhat smooth curve through scatters of observed outcomes, Y,
  versus fitted propensity scores, X, for the patients in each of the two treatment groups,
  one can consider the question: "Over the range where both smooth curves are defined (i.e. their
  common support), what is the (weighted) average signed difference between these two curves?"

  UNSUPERVISED NEAREST NEIGHBORS / LOCAL TREATMENT DIFFERENCES:
  
  Multiple calls to UPSnnltd(n) for varying numbers of clusters, n, are typically made
  after first invoking UPShclus() to hierarchically cluster patients in X-space and then
  invoking UPSaccum() to specify a Y outcome variable and a two-level (binary) treatment
  factor t. UPSnnltd(n) then determines the LTD Distribution corresponding to n clusters
  and, optionally, displays this distribution in a "Snowball" plot.
  
  UNSUPERVISED INSTRUMENTAL VARIABLES / LOCAL AVERAGE y-OUTCOME EFFECTS:
    
  The Observed Propensity Score (OPS) is defined here to be the local (within-cluster) observed
  fraction of experimental units (patients) choosing the new treatment (t=1) over the control
  treatment (t=0). Multiple calls to UPSivadj(n) for varying numbers of clusters, n, then yield
  alternative linear fits to LAO estimates plotted versus their X = OPS. The slope of each such
  fit determines both the direction and strength of CER preferences for treatment or control.
}
\author{Bob Obenchain <wizbob@att.net>}
\references{
  Green PJ, Silverman BW. (1994) \bold{Nonparametric Regression and Generalized Linear Models:
  A Roughness Penalty Approach}. \emph{Chapman and Hall}.
  
  McClellan M, McNeil BJ, Newhouse JP. (1994) Does More Intensive Treatment of
  Myocardial Infarction in the Elderly Reduce Mortality?: Analysis Using Instrumental
  Variables. \emph{JAMA} \bold{272}: 859-866.  
  
  Obenchain RL. (2004) Unsupervised Propensity Scoring: NN and IV Plots.
  \emph{Proceedings of the American Statistical Association (on CD)} 8 pages.
 
  Obenchain RL. (2018) \bold{USPS_in_R.pdf} http://localcontrolstatistics.org  40 pages.
  
  Rosenbaum PR, Rubin RB. (1983) The Central Role of the Propensity Score
  in Observational Studies for Causal Effects. \emph{Biometrika} \bold{70}:
  41-55.

  Rubin DB. (1980) Bias reduction using Mahalanobis metric matching.
  \emph{Biometrics} \bold{36}: 293-298.
}
\keyword{package}
\examples{
  demo(abcix)
}